@@ -32,7 +32,8 @@ if(identical(.ref, c(" - ", "ref"))){
 ###if((length(.ref) == 2) && all(.ref == c(" - ", "ref"))){
 	.reference.method <- "ref.cat"
 	.ref.cat <- which(.tab$reference == "ref")
-} else stop("Could not figure out reference. Something seems to be wrong with the haptable.")
+} else stop("Could not figure out reference. Something seems to be wrong with
+the haptable.", call. = F)
 #
 ## EXTRACT HAPLOTYPE FREQUENCIES
 .p <- .tab[, c("haplofreq", "haplofreq.lower", "haplofreq.upper")]
